# HGMD Regulatory Variants

The goal of this analysis was to get a list of regulatory variants from HGMD and a set of corresponding matched variants from the 1000 genomes project data. About 150 variants without any annotated protein-coding effect were found and matched successfully.

The VCF files with HGMD and 1000 genomes variants about 5% allele frequency are `matched_variants_hgmd.vcf.gz` and `matched_variants_tg.vcf.gz` respectively.

# Workflow

## Getting Data from HGMD
The following post details how I got these variants out of HGMD:
http://labnotebook.andrewjohnhill.com/2014/09/25/mysql-and-regulatory-variants-in-hgmd/

## Generating CADD Annotations
Once I got the .txt files, I made a VCF file from the output by simply extracting the correponding columns.

I generated CADD annotations using the following script on the VCF:
```
/net/shendure/vol1/home/mkircher/simulation/cadd_v1.1/scripts/annotateVEP.py hgmd_regulatory.vcf hgmd_regulatory_cadd.txt.gz
```

## Getting Matched Variants
I then wanted to get a set of matched variants from 1000 genomes. I used the CADD annotation of 1000 genomes data here:
```
/net/shendure/vol1/home/mkircher/simulation/cadd_v1.1/datasets/1000G/1000G_SNVs.anno.tsv.gz
```

To extract the matched variants and exclude any variants with any coding impact, I used a python script:

For usage
```
python generate_matched_variants.py --help
```

Example
```
python generate_matched_variants.py --source /net/shendure/vol1/home/mkircher/simulation/cadd_v1.1/datasets/1000G/1000G_SNVs.anno.tsv.gz --variants hgmd_regulatory_sorted_cadd.txt.gz --output_source matched_variants_tg.txt.gz --output_variants matched_variants_hgmd.txt.gz
```

## VCF
I converted these annotation files with bash:

```
cat matched_variants_hgmd.txt | awk 'BEGIN {OFS='\t'}{print $1, $2, ".", $3, $4, $5}' | gzip > matched_variants_hgmd.vcf.gz
cat matched_variants_tg.txt | awk 'BEGIN {OFS='\t'}{print $1, $2, ".", $3, $4, $5}' | gzip > matched_variants_tg.vcf.gz
```
